@@ -9,7 +9,7 @@ from __future__ import unicode_literals
 __author__ = 'Florian Rhiem (florian.rhiem@gmail.com)'
 __copyright__ = 'Copyright (c) 2013-2019 Florian Rhiem'
 __license__ = 'MIT'
-__version__ = '1.8.3'
+__version__ = '1.8.5'
 
 # By default (ERROR_REPORTING = True), GLFW errors will be reported as Python
 # exceptions. Set ERROR_REPORTING to False or set a curstom error callback to
@@ -1286,9 +1286,9 @@ if hasattr(_glfw, 'glfwGetWindowContentScale'):
         Wrapper for:
             void glfwGetWindowContentScale(GLFWwindow* window, float* xscale, float* yscale);
         """
-        xscale_value = ctypes.c_int(0)
+        xscale_value = ctypes.c_float(0)
         xscale = ctypes.pointer(xscale_value)
-        yscale_value = ctypes.c_int(0)
+        yscale_value = ctypes.c_float(0)
         yscale = ctypes.pointer(yscale_value)
         _glfw.glfwGetWindowContentScale(window, xscale, yscale)
         return xscale_value.value, yscale_value.value
